// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.

var DotNetEntropyLib = {
    $DOTNETENTROPY: {
        // batchedQuotaMax is the max number of bytes as specified by the api spec.
        // If the byteLength of array is greater than 65536, throw a QuotaExceededError and terminate the algorithm.
        // https://www.w3.org/TR/WebCryptoAPI/#Crypto-method-getRandomValues
        batchedQuotaMax: 65536,
        getBatchedRandomValues: function (buffer, bufferLength) {
            // for modern web browsers
            // map the work array to the memory buffer passed with the length
            for (var i = 0; i < bufferLength; i += this.batchedQuotaMax) {
                var view = new Uint8Array(Module.HEAPU8.buffer, buffer + i, Math.min(bufferLength - i, this.batchedQuotaMax));
                crypto.getRandomValues(view)
            }
        }
    },
    dotnet_browser_entropy : function (buffer, bufferLength) {
        // check that we have crypto available
        if (typeof crypto === 'object' && typeof crypto['getRandomValues'] === 'function') {
            DOTNETENTROPY.getBatchedRandomValues(buffer, bufferLength)
            return 0;
        } else {
            // we couldn't find a proper implementation, as Math.random() is not suitable
            // instead of aborting here we will return and let managed code handle the message
            return -1;
        }
    },
};

autoAddDeps(DotNetEntropyLib, '$DOTNETENTROPY')
mergeInto(LibraryManager.library, DotNetEntropyLib)

// SIG // Begin signature block
// SIG // MIIojgYJKoZIhvcNAQcCoIIofzCCKHsCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // He0Yy7K+G59QXMN5sHHtOtGJyoFg0Ie3YpqLi1MNoKeg
// SIG // gg3wMIIGbjCCBFagAwIBAgITMwAAAwVNYg1ohQeqMwAA
// SIG // AAADBTANBgkqhkiG9w0BAQwFADB+MQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMH
// SIG // UmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBv
// SIG // cmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBT
// SIG // aWduaW5nIFBDQSAyMDExMB4XDTIyMDgwNDIwMjM1N1oX
// SIG // DTIzMDgwMzIwMjM1N1owYzELMAkGA1UEBhMCVVMxEzAR
// SIG // BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1v
// SIG // bmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
// SIG // bjENMAsGA1UEAxMELk5FVDCCAaIwDQYJKoZIhvcNAQEB
// SIG // BQADggGPADCCAYoCggGBALgT1J98uPoa1weiQsnOFH3y
// SIG // L9VcrQ5JLGIZT50ZFJp4cOpQ+gHtRxxVE89hPiTPzLAR
// SIG // VHaubXNodZsBmWk4PbWNkPwm0aKis02uN71Farp9Ouc5
// SIG // 0Pzn1DT+R3+e3ahXLhtC5mlTaCZiJ4AU3blyaqQLKLeJ
// SIG // a3pqyHBnJiXySNBrhLBkleguDLiqBLaziCWbQLAIlLUl
// SIG // ypI/cutECrDKU4/f7PHM+1gUQdK+WZnH/+t82oAY0VXG
// SIG // 3pUMZzv3UysNO4CS1aFAjQG5cjdJuS812n658mOSIPwF
// SIG // 5zmfaIH14qh/XPyfi0a6WdZaZIRth3dnP9VcGN1sDSuc
// SIG // RV/no9+aSPqWyt19ipN4jiuJILUHhm+3eekt2KGaKWys
// SIG // 2whswE1RkBoAq7GmvFIrXvcEB0mqM/09bIfgvkjN50z/
// SIG // 5XmMlyrqtmD0Fe+V1DTbfOyhdBZpt4G2cbqK3eoFUoJI
// SIG // ytn3N06zIBT0kd8BVWDWKOTi0VHsXx8cvHDKDLOL5iK2
// SIG // REcibwIDAQABo4IBfjCCAXowHwYDVR0lBBgwFgYKKwYB
// SIG // BAGCN0wIAQYIKwYBBQUHAwMwHQYDVR0OBBYEFMPGGeTy
// SIG // z3Y+F0AQcJOKcmziq1YbMFAGA1UdEQRJMEekRTBDMSkw
// SIG // JwYDVQQLEyBNaWNyb3NvZnQgT3BlcmF0aW9ucyBQdWVy
// SIG // dG8gUmljbzEWMBQGA1UEBRMNNDY0MjIzKzQ3MjIzNzAf
// SIG // BgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBU
// SIG // BgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jv
// SIG // c29mdC5jb20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUw
// SIG // UzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3Nv
// SIG // ZnQuY29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0Ey
// SIG // MDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAw
// SIG // DQYJKoZIhvcNAQEMBQADggIBAGhKSnmsyGvycL6Dw4uq
// SIG // 3wDtwdM/hSbG6b5NqxUtIoE9TMT4Uqj+NWtYfrB09uq8
// SIG // OzxkLHnaEec19x5EyVxy+DBpbmzNU3/469qF4kyp0FNj
// SIG // CJlmFgFoxLNFzisxKeTXw1pFppM5AxHG+/VqIdQlOCbc
// SIG // 2nTSJLqxag4G3J+fsEE6uywxw6NxfieRBzAJd2HGPLUV
// SIG // pt87GLklNjsyxDUJYkxFtgkj1khGqwIG6ZNkbIXPsxR8
// SIG // S9oiKqAP71cZEwN6+TnnPIotqXeBsC+urL/NB8NWxBEe
// SIG // npVFFF4zNXd3sbmb4H/668DKQaIP5Qm0Ige2nmxgXAPq
// SIG // 9CPYZawXOvxOhOFgiU3AtLFAK/Oc+sgkXCeLX2A6RKq8
// SIG // SqgwHwtjWXaviyEToDFwSMdel+y+9wSZokXBwr+7TjGL
// SIG // uRinndUGjiVtJU/rsz/y9xC5TiOn6BAjwXB0EktoM0dP
// SIG // cTu3d9AC0q2gylEwTPAdfSbpABG+IPHEgtOoDxSBxUGc
// SIG // hdEElyklcwz6C8oGSXR6CVGHV7QW+cH03C9DH7nBBhAh
// SIG // UIojqCYwKb9b8Gam25brrUFwf8to5dXLZ14HYeRA9c6A
// SIG // H2CBwiE4ABPpOq/iypGWil8Vyg3Uf6LmgAEMMxZYLtNg
// SIG // 5GbM3tcTW2M3C0EZFIpiuT43hvm8uNHpXAZP3PJ3yCc5
// SIG // yR09MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
// SIG // hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNV
// SIG // BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
// SIG // HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEy
// SIG // MDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNh
// SIG // dGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1OTA5
// SIG // WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWdu
// SIG // aW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOC
// SIG // Ag8AMIICCgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGf
// SIG // Qhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDI
// SIG // OdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv
// SIG // 2akrrnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13Y
// SIG // xC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT
// SIG // +OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
// SIG // 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nk
// SIG // kDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
// SIG // OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVf
// SIG // GCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4ji
// SIG // JV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA4bys
// SIG // AoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLn
// SIG // JN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeB
// SIG // e+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ecXL93KCjx
// SIG // 7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwT
// SIG // XWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEA
// SIG // AaOCAe0wggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1Ud
// SIG // DgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEE
// SIG // AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYw
// SIG // DwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToC
// SIG // MZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBL
// SIG // hklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
// SIG // bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFf
// SIG // MDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
// SIG // BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
// SIG // aS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNf
// SIG // MjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQBgjcu
// SIG // AzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNy
// SIG // b3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMu
// SIG // aHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBnAGEAbABf
// SIG // AHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQA
// SIG // LiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou
// SIG // 09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+
// SIG // vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzS
// SIG // Gksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlE
// SIG // PXh6I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6V
// SIG // oCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu
// SIG // 5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
// SIG // STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBp
// SIG // mLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
// SIG // bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HN
// SIG // pZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7f
// SIG // QccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmAH9AA
// SIG // KcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3
// SIG // S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8
// SIG // MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF670EKsT/7
// SIG // qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJ
// SIG // UnMTDXpQzTGCGfYwghnyAgEBMIGVMH4xCzAJBgNVBAYT
// SIG // AlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQH
// SIG // EwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
// SIG // cG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2Rl
// SIG // IFNpZ25pbmcgUENBIDIwMTECEzMAAAMFTWINaIUHqjMA
// SIG // AAAAAwUwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcN
// SIG // AQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
// SIG // MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIKTQ
// SIG // ts56jQmXdTOrJhxHePDRP6IYHMqtdIFdJu6K2KWDMEIG
// SIG // CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBv
// SIG // AGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20w
// SIG // DQYJKoZIhvcNAQEBBQAEggGAQQwHtLKIyVtgWoCqVsWv
// SIG // 4Bb/1jXrDx1cHMgtLhO2IfCl0IAt225VJnBz9khi4eks
// SIG // 4joPvjDAR3hxDVNE5r18kXquLb04I8x2MltCubELdP5h
// SIG // G6ChD3Zg9GNhhKeZXxb17ummzGwqAGspqvLBgJt0wfSK
// SIG // DZXhSZbohjel3cicJzpD0LrdH5D5I1IL10LEfVdKTNUL
// SIG // B9VKBAuX0bVgRWNJbIYV3XpKgPim8e+sBhPiWPBQrGah
// SIG // RTmhdcme8S69gx41RJZD8RbfxMiCCOuEHXqpeC4nprO2
// SIG // x9lNgdCdKvlWES5/NSNKmkCdZnLIUYLmaf1ThSSxUv12
// SIG // xqKxtdO7kYZ/ZgYb56+fAyboXdqEHBh+7z8SVtfP8xDh
// SIG // KtQB5QlT0Yig4/JqfEvQ7fs5PYs90PaqYpTGPR+iUwEd
// SIG // M2xnnpfLw9MERMA4Pk/GHSYGzHcBn2QNs3tbOtiTu9cS
// SIG // PJx4nVrPEP038J3UikE4U7WbegtWcva1nmoLSaWgKV2h
// SIG // bBA73iB4oYIXADCCFvwGCisGAQQBgjcDAwExghbsMIIW
// SIG // 6AYJKoZIhvcNAQcCoIIW2TCCFtUCAQMxDzANBglghkgB
// SIG // ZQMEAgEFADCCAVEGCyqGSIb3DQEJEAEEoIIBQASCATww
// SIG // ggE4AgEBBgorBgEEAYRZCgMBMDEwDQYJYIZIAWUDBAIB
// SIG // BQAEIB+G11lKVwuucvxaFPbi9NMrkUnSKOjiMh1IwcjN
// SIG // 8A6xAgZjI1S2JCEYEzIwMjIwOTI4MTg0ODE0LjEzOFow
// SIG // BIACAfSggdCkgc0wgcoxCzAJBgNVBAYTAlVTMRMwEQYD
// SIG // VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
// SIG // MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
// SIG // JTAjBgNVBAsTHE1pY3Jvc29mdCBBbWVyaWNhIE9wZXJh
// SIG // dGlvbnMxJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOkFF
// SIG // MkMtRTMyQi0xQUZDMSUwIwYDVQQDExxNaWNyb3NvZnQg
// SIG // VGltZS1TdGFtcCBTZXJ2aWNloIIRVzCCBwwwggT0oAMC
// SIG // AQICEzMAAAGWSVti4S/d908AAQAAAZYwDQYJKoZIhvcN
// SIG // AQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldh
// SIG // c2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
// SIG // BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UE
// SIG // AxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
// SIG // HhcNMjExMjAyMTkwNTEzWhcNMjMwMjI4MTkwNTEzWjCB
// SIG // yjELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UECxMcTWlj
// SIG // cm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEmMCQGA1UE
// SIG // CxMdVGhhbGVzIFRTUyBFU046QUUyQy1FMzJCLTFBRkMx
// SIG // JTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNl
// SIG // cnZpY2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIK
// SIG // AoICAQDSH2wQC2+t/jzA6jL6LZMhDNJG0nv1cUqe+H4M
// SIG // GKyEgRZUwp1YsHl1ITGyi8K9rkPRKKKAi0lT8g0b1GIi
// SIG // pkWc8qCtE3wibxoNR4mCyrvgEsXutnbxI1obx8cMfa2X
// SIG // gchG/XBGZcFtGd0UQvXkxUYvokfG1TyBMqnIZvQ2Ltcm
// SIG // Gj86laPRNuRodkEM7VVUO2oMSHJbaTNj1b2kAC8sqlyt
// SIG // H1zmfrQpTA3rZOyEmywT43DRfsNlXmkNKMiW7BafNnHZ
// SIG // LGHGacpimE4doDMur3yiH/qCCx2PO4pIqkA6WLGSN8yh
// SIG // YavcQZRFVtsl/x/IiuL0fxPGpQmRc84m41yauncveNh/
// SIG // 5/14MqsZ7ugY1ix8fkOYgJBlLss8myPhaMA6qcEB/RWW
// SIG // qcCfhyARNjCcmBNGNXeMgKyZ/+e3bCOlXmWeDtVJDLmO
// SIG // tzEDBLmkg2/etp3T9hOX+LodYwdBkY2noCDEzPWVa834
// SIG // AmkJvR6ynEeBGj6ouWifpXxaobBdasb0+r/9eYr+T00y
// SIG // rLFn16rrTULnVzkW7lLyXWEousvzYnul3HPCQooQS4LY
// SIG // 1HBKTyTSftGX56ZgOz7Rk+esvbcr+NjLvBBy7Xeomgku
// SIG // w1F/Uru7lZ9AR+EQbpg2pvCHSarMQQHbf1GXPhlDTHwk
// SIG // eskRiz5jPjTr1Wz/f+9CZx5ovtTF0QIDAQABo4IBNjCC
// SIG // ATIwHQYDVR0OBBYEFNLfCNksLmWtIGEsiYuEKprRzXSy
// SIG // MB8GA1UdIwQYMBaAFJ+nFV0AXmJdg/Tl0mWnG1M1Gely
// SIG // MF8GA1UdHwRYMFYwVKBSoFCGTmh0dHA6Ly93d3cubWlj
// SIG // cm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jvc29mdCUy
// SIG // MFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNybDBs
// SIG // BggrBgEFBQcBAQRgMF4wXAYIKwYBBQUHMAKGUGh0dHA6
// SIG // Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMv
// SIG // TWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIw
// SIG // MTAoMSkuY3J0MAwGA1UdEwEB/wQCMAAwEwYDVR0lBAww
// SIG // CgYIKwYBBQUHAwgwDQYJKoZIhvcNAQELBQADggIBAK9g
// SIG // CxC4IVbYKVQBHP5ztJc/kfgSubcL5hTReVE1uwSVKp92
// SIG // Sfd/IIvFgGQcwVlAZc8DubOhTshlR2fSFfK6+sUzoMOu
// SIG // f9ItKF7m348+SpZ455iITDyTgEjqXhTmTTvBfyEHA6gx
// SIG // HGzVo578k2Qsc7qSuXmPr8ZkeuRNHNOxFRQmnUWmdTOL
// SIG // GJlbJq9zTH+KYbnJZ2tK5xwT2d2irtBu7U/FruzCxSbn
// SIG // M00y6dpYZcMUCdLuzxHEnX8/epO1nQlrpUTpJ6gel2Pv
// SIG // +E+4oktdX8zz0Y0WfwdQOZVbn5gr/wPLvIoceKJJ366A
// SIG // A36lbc8Do5h6TSvJbVArNutbg/1JcCT5Tl9peMEmiK1b
// SIG // 3z5kRFZffztUe9pNYnhijkGaQnRTbsBqXaCCLmPU9i4P
// SIG // EHcOyh8z7t5tzjOAnQYXi7oNBbRXitz8XbPK2XasNB9Q
// SIG // aU+01TKZRlVtYlsWrDriN7xCwCcx4bUnyiHGNiV5reIs
// SIG // DMbCKZ7h1sxLIQeg5tW/Mg3R30EnzjFV5cq8RPXvoaFj
// SIG // 89LpFMlmJbk8+KFmHzwXcl5wS+GVy38VulA+36aEM4FA
// SIG // DKqMjW10FCUEVVfznFZ3UlGdSS7GqyFeoXBzEqvwaIWx
// SIG // v0BXvLtNPfR+YxOzeCaeiMVC3cx0PlDcz+AF/VN2WHKI
// SIG // 81dOAmE/qLJkd/EpmLZzMIIHcTCCBVmgAwIBAgITMwAA
// SIG // ABXF52ueAptJmQAAAAAAFTANBgkqhkiG9w0BAQsFADCB
// SIG // iDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
// SIG // b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
// SIG // Y3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWlj
// SIG // cm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5
// SIG // IDIwMTAwHhcNMjEwOTMwMTgyMjI1WhcNMzAwOTMwMTgz
// SIG // MjI1WjB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
// SIG // aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
// SIG // ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQD
// SIG // Ex1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDCC
// SIG // AiIwDQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAOTh
// SIG // pkzntHIhC3miy9ckeb0O1YLT/e6cBwfSqWxOdcjKNVf2
// SIG // AX9sSuDivbk+F2Az/1xPx2b3lVNxWuJ+Slr+uDZnhUYj
// SIG // DLWNE893MsAQGOhgfWpSg0S3po5GawcU88V29YZQ3MFE
// SIG // yHFcUTE3oAo4bo3t1w/YJlN8OWECesSq/XJprx2rrPY2
// SIG // vjUmZNqYO7oaezOtgFt+jBAcnVL+tuhiJdxqD89d9P6O
// SIG // U8/W7IVWTe/dvI2k45GPsjksUZzpcGkNyjYtcI4xyDUo
// SIG // veO0hyTD4MmPfrVUj9z6BVWYbWg7mka97aSueik3rMvr
// SIG // g0XnRm7KMtXAhjBcTyziYrLNueKNiOSWrAFKu75xqRdb
// SIG // Z2De+JKRHh09/SDPc31BmkZ1zcRfNN0Sidb9pSB9fvzZ
// SIG // nkXftnIv231fgLrbqn427DZM9ituqBJR6L8FA6PRc6ZN
// SIG // N3SUHDSCD/AQ8rdHGO2n6Jl8P0zbr17C89XYcz1DTsEz
// SIG // OUyOArxCaC4Q6oRRRuLRvWoYWmEBc8pnol7XKHYC4jMY
// SIG // ctenIPDC+hIK12NvDMk2ZItboKaDIV1fMHSRlJTYuVD5
// SIG // C4lh8zYGNRiER9vcG9H9stQcxWv2XFJRXRLbJbqvUAV6
// SIG // bMURHXLvjflSxIUXk8A8FdsaN8cIFRg/eKtFtvUeh17a
// SIG // j54WcmnGrnu3tz5q4i6tAgMBAAGjggHdMIIB2TASBgkr
// SIG // BgEEAYI3FQEEBQIDAQABMCMGCSsGAQQBgjcVAgQWBBQq
// SIG // p1L+ZMSavoKRPEY1Kc8Q/y8E7jAdBgNVHQ4EFgQUn6cV
// SIG // XQBeYl2D9OXSZacbUzUZ6XIwXAYDVR0gBFUwUzBRBgwr
// SIG // BgEEAYI3TIN9AQEwQTA/BggrBgEFBQcCARYzaHR0cDov
// SIG // L3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9Eb2NzL1Jl
// SIG // cG9zaXRvcnkuaHRtMBMGA1UdJQQMMAoGCCsGAQUFBwMI
// SIG // MBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBBMAsGA1Ud
// SIG // DwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8GA1UdIwQY
// SIG // MBaAFNX2VsuP6KJcYmjRPZSQW9fOmhjEMFYGA1UdHwRP
// SIG // ME0wS6BJoEeGRWh0dHA6Ly9jcmwubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1dF8y
// SIG // MDEwLTA2LTIzLmNybDBaBggrBgEFBQcBAQROMEwwSgYI
// SIG // KwYBBQUHMAKGPmh0dHA6Ly93d3cubWljcm9zb2Z0LmNv
// SIG // bS9wa2kvY2VydHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYt
// SIG // MjMuY3J0MA0GCSqGSIb3DQEBCwUAA4ICAQCdVX38Kq3h
// SIG // LB9nATEkW+Geckv8qW/qXBS2Pk5HZHixBpOXPTEztTnX
// SIG // wnE2P9pkbHzQdTltuw8x5MKP+2zRoZQYIu7pZmc6U03d
// SIG // mLq2HnjYNi6cqYJWAAOwBb6J6Gngugnue99qb74py27Y
// SIG // P0h1AdkY3m2CDPVtI1TkeFN1JFe53Z/zjj3G82jfZfak
// SIG // Vqr3lbYoVSfQJL1AoL8ZthISEV09J+BAljis9/kpicO8
// SIG // F7BUhUKz/AyeixmJ5/ALaoHCgRlCGVJ1ijbCHcNhcy4s
// SIG // a3tuPywJeBTpkbKpW99Jo3QMvOyRgNI95ko+ZjtPu4b6
// SIG // MhrZlvSP9pEB9s7GdP32THJvEKt1MMU0sHrYUP4KWN1A
// SIG // PMdUbZ1jdEgssU5HLcEUBHG/ZPkkvnNtyo4JvbMBV0lU
// SIG // ZNlz138eW0QBjloZkWsNn6Qo3GcZKCS6OEuabvshVGtq
// SIG // RRFHqfG3rsjoiV5PndLQTHa1V1QJsWkBRH58oWFsc/4K
// SIG // u+xBZj1p/cvBQUl+fpO+y/g75LcVv7TOPqUxUYS8vwLB
// SIG // gqJ7Fx0ViY1w/ue10CgaiQuPNtq6TPmb/wrpNPgkNWcr
// SIG // 4A245oyZ1uEi6vAnQj0llOZ0dFtq0Z4+7X6gMTN9vMvp
// SIG // e784cETRkPHIqzqKOghif9lwY1NNje6CbaUFEMFxBmoQ
// SIG // tB1VM1izoXBm8qGCAs4wggI3AgEBMIH4oYHQpIHNMIHK
// SIG // MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3Rv
// SIG // bjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
// SIG // cm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNy
// SIG // b3NvZnQgQW1lcmljYSBPcGVyYXRpb25zMSYwJAYDVQQL
// SIG // Ex1UaGFsZXMgVFNTIEVTTjpBRTJDLUUzMkItMUFGQzEl
// SIG // MCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2Vy
// SIG // dmljZaIjCgEBMAcGBSsOAwIaAxUA0PommlVZaduKtDHg
// SIG // hztBZDfmVv6ggYMwgYCkfjB8MQswCQYDVQQGEwJVUzET
// SIG // MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
// SIG // bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0
// SIG // aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFt
// SIG // cCBQQ0EgMjAxMDANBgkqhkiG9w0BAQUFAAIFAObe9esw
// SIG // IhgPMjAyMjA5MjkwMDMzNDdaGA8yMDIyMDkzMDAwMzM0
// SIG // N1owdzA9BgorBgEEAYRZCgQBMS8wLTAKAgUA5t716wIB
// SIG // ADAKAgEAAgIp0QIB/zAHAgEAAgIRvTAKAgUA5uBHawIB
// SIG // ADA2BgorBgEEAYRZCgQCMSgwJjAMBgorBgEEAYRZCgMC
// SIG // oAowCAIBAAIDB6EgoQowCAIBAAIDAYagMA0GCSqGSIb3
// SIG // DQEBBQUAA4GBAIVqyJ56xBXWfDs1Ini3sUYCJgP42oWx
// SIG // RdklN54+Yf2bx1B4wvytCc6qbH6nzlLlYTWG/0xjwXXi
// SIG // VRscZFh60pTG9XMfcMATDJ2N4L67P33iJAuE7RCQZ6O1
// SIG // Aw7+cOXzeQKOR1LBFpc26iaVeZMejJ4UtLkR8bY/HLv0
// SIG // RXPfMO0lMYIEDTCCBAkCAQEwgZMwfDELMAkGA1UEBhMC
// SIG // VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcT
// SIG // B1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
// SIG // b3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUt
// SIG // U3RhbXAgUENBIDIwMTACEzMAAAGWSVti4S/d908AAQAA
// SIG // AZYwDQYJYIZIAWUDBAIBBQCgggFKMBoGCSqGSIb3DQEJ
// SIG // AzENBgsqhkiG9w0BCRABBDAvBgkqhkiG9w0BCQQxIgQg
// SIG // DYgvxmcyhSWmoZC62mu4aZaq3gIZNFV1pV68CXGGlu8w
// SIG // gfoGCyqGSIb3DQEJEAIvMYHqMIHnMIHkMIG9BCB2BNYC
// SIG // +B0105J2Ry6CfnZ0JA8JflZQQ6sLpHI3LbK9kDCBmDCB
// SIG // gKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
// SIG // aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
// SIG // ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMT
// SIG // HU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwAhMz
// SIG // AAABlklbYuEv3fdPAAEAAAGWMCIEILzuhNIEqPeBqFiJ
// SIG // uLYDWBIxKsX/L9oCD49BLWidg91eMA0GCSqGSIb3DQEB
// SIG // CwUABIICAKr9OG8th+bBufeCQ3WOYbqqemgTFrujx199
// SIG // wc7/nLnVF7ERQh5qqo6xrFVTe0hRbHzR7o3wqAYkArBE
// SIG // V3HOqDLAaIHCKB5fPfslHYSD21cQKAlQ9X+zIN1ZlW8G
// SIG // 5VYbPn8ZWLtCnPFRwko2s9aPWzFxljuQ2PwGdE6sOdtP
// SIG // 3Z7iLdcmHJiNSuOLjjJcV6eIhrPxDpVgrjGtxPE1P9Zc
// SIG // x01tXw/ddCpUoUhiSbHXXWNNeYzjCC9JdVkmYag67kmz
// SIG // LAN4PF5/qjIZ0Ypda7QWwqPPW//K7EwmtFlATvXDnE1/
// SIG // Uua3RHR1euIOQEDq6xWdmIHLO2W/4gwg++FiS0Cb/CH2
// SIG // CnELW5yx/fdHswm3DfzmhnBKbgX16Ip9by7eVpoTO1Ki
// SIG // 2x/btn+lE8ggcaX1IX/tlCl3mrsnnPwcJOHIgPmNT3LG
// SIG // RZBgYG98LFmmJPyz4EUyYQN65t0bUodcd6f8X9dbM/xD
// SIG // +ETueLx50Rb1MNaiReEcRJLLFQIW4Gv60lRG0cNGmBsu
// SIG // /SuSOyWUIiav92eEGqb3CdBMuwpqm8aPLjHGNhDDoe/D
// SIG // 1/cH/BcwkFsFqUk/XWEAm3gmyNxBSXcQrZtQIde0qKpS
// SIG // xQvDN+4b047UBslW/f0JuxEL3y6x1Jh6RWJM49iLg3F+
// SIG // CzEeo5grih6oJDRGQHjrDjuDcK7yDibU
// SIG // End signature block
